==> refcodes-matcher-1.3.3-sources.jar: org/refcodes/matcher/WildcardSubstitutesImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.matcher;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.refcodes.mixin.Dumpable;

/**
 * The Class WildcardSubstitutesImpl.
 */
public class WildcardSubstitutesImpl implements WildcardSubstitutes, Dumpable {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private String[] _wildcardSubstitutes;

	private Map<String, String> _namedWildcardSubstittutes;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new wildcard substitutes impl.
	 *
	 * @param aWildcardSubstitutes the wildcard substitutes
	 * @param aNamedWildcardSubstittutes the named wildcard substittutes
	 */
	public WildcardSubstitutesImpl( String[] aWildcardSubstitutes, Map<String, String> aNamedWildcardSubstittutes ) {
		_wildcardSubstitutes = aWildcardSubstitutes;
		_namedWildcardSubstittutes = aNamedWildcardSubstittutes;
	}

	// /////////////////////////////////////////////////////////////////////////
	// INJECTION:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacements() {
		return _wildcardSubstitutes;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getWildcardReplacementAt( int aIndex ) {
		if ( _wildcardSubstitutes != null ) {
			if ( _wildcardSubstitutes.length > aIndex ) {
				return _wildcardSubstitutes[aIndex];
			}
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getWildcardReplacement( String aWildcardName ) {
		if ( _namedWildcardSubstittutes != null ) {
			return _namedWildcardSubstittutes.get( aWildcardName );
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacements( String... aWildcardNames ) {
		List<String> theWildcardSubstitutes = new ArrayList<>();
		String eSubstitute;
		for ( String eName : aWildcardNames ) {
			eSubstitute = getWildcardReplacement( eName );
			if ( eSubstitute == null ) {
				throw new IllegalArgumentException( "There is none such named wildcard substitute for name <" + eName + ">, check your pattern!." );
			}
			theWildcardSubstitutes.add( eSubstitute );
		}
		return theWildcardSubstitutes.toArray( new String[theWildcardSubstitutes.size()] );
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacementsAt( int... aIndexes ) {
		List<String> theWildcardSubstitutes = new ArrayList<>();
		for ( int i : aIndexes ) {
			if ( i >= _wildcardSubstitutes.length ) {
				throw new IllegalArgumentException( "Your provided index <" + i + "> exceeds the number of wildcards <" + _wildcardSubstitutes.length + "> defined in your pattern." );
			}
			theWildcardSubstitutes.add( _wildcardSubstitutes[i] );
		}
		return theWildcardSubstitutes.toArray( new String[theWildcardSubstitutes.size()] );
	}

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////

}

==> refcodes-matcher-1.10.2-sources.jar: org/refcodes/matcher/WildcardSubstitutesImpl.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.matcher;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.refcodes.mixin.Dumpable;

/**
 * The Class WildcardSubstitutesImpl.
 */
public class WildcardSubstitutesImpl implements WildcardSubstitutes, Dumpable {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private String[] _wildcardSubstitutes;

	private Map<String, String> _namedWildcardSubstittutes;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new wildcard substitutes impl.
	 *
	 * @param aWildcardSubstitutes the wildcard substitutes
	 * @param aNamedWildcardSubstittutes the named wildcard substittutes
	 */
	public WildcardSubstitutesImpl( String[] aWildcardSubstitutes, Map<String, String> aNamedWildcardSubstittutes ) {
		_wildcardSubstitutes = aWildcardSubstitutes;
		_namedWildcardSubstittutes = aNamedWildcardSubstittutes;
	}

	// /////////////////////////////////////////////////////////////////////////
	// INJECTION:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacements() {
		return _wildcardSubstitutes;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getWildcardReplacementAt( int aIndex ) {
		if ( _wildcardSubstitutes != null ) {
			if ( _wildcardSubstitutes.length > aIndex ) {
				return _wildcardSubstitutes[aIndex];
			}
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getWildcardReplacement( String aWildcardName ) {
		if ( _namedWildcardSubstittutes != null ) {
			return _namedWildcardSubstittutes.get( aWildcardName );
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacements( String... aWildcardNames ) {
		List<String> theWildcardSubstitutes = new ArrayList<>();
		String eSubstitute;
		for ( String eName : aWildcardNames ) {
			eSubstitute = getWildcardReplacement( eName );
			if ( eSubstitute == null ) {
				throw new IllegalArgumentException( "There is none such named wildcard substitute for name <" + eName + ">, check your pattern!." );
			}
			theWildcardSubstitutes.add( eSubstitute );
		}
		return theWildcardSubstitutes.toArray( new String[theWildcardSubstitutes.size()] );
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String[] getWildcardReplacementsAt( int... aIndexes ) {
		List<String> theWildcardSubstitutes = new ArrayList<>();
		for ( int i : aIndexes ) {
			if ( i >= _wildcardSubstitutes.length ) {
				throw new IllegalArgumentException( "Your provided index <" + i + "> exceeds the number of wildcards <" + _wildcardSubstitutes.length + "> defined in your pattern." );
			}
			theWildcardSubstitutes.add( _wildcardSubstitutes[i] );
		}
		return theWildcardSubstitutes.toArray( new String[theWildcardSubstitutes.size()] );
	}

	@Override
	public String[] getWildcardNames() {
		if ( _namedWildcardSubstittutes != null && _namedWildcardSubstittutes.size() != 0 ) {
			return _namedWildcardSubstittutes.keySet().toArray( new String[_namedWildcardSubstittutes.size()] );
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return "WildcardSubstitutesImpl [wildcardSubstitutes=" + Arrays.toString( _wildcardSubstitutes ) + ", namedWildcardSubstittutes=" + _namedWildcardSubstittutes + "]";
	}

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////

}
